Actions
=======

.. contents:: :local:

:mod:`add_config`
-----------------

.. automodule:: actions.add_config
    :members:

:mod:`copy_file`
----------------

.. automodule:: actions.copy_file
    :members:

:mod:`install_cli_plugin`
-------------------------

.. automodule:: actions.install_cli_plugin
    :members:

:mod:`install_extension`
------------------------

.. automodule:: actions.install_extension
    :members:

:mod:`install_image`
--------------------

.. automodule:: actions.install_image
    :members:

:mod:`replace_config`
---------------------

.. automodule:: actions.replace_config
    :members:

:mod:`send_email`
-----------------

.. automodule:: actions.send_email
    :members:

:mod:`run_bash_script`
----------------------

.. automodule:: actions.run_bash_script
    :members:

:mod:`run_cli_commands`
-----------------------

.. automodule:: actions.run_cli_commands
    :members:

..
   #:mod:`template`
   #---------------
   #
   #.. automodule:: template
   #    :members:

